@@ -52,9 +52,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -68,9 +68,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -84,7 +84,7 @@ enum
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -92,17 +92,25 @@ class SGDI_API_DLL_EXPORT CSG_3DView_Panel : public wxPanel, public CSG_3DView_C
 {
 public:
 	CSG_3DView_Panel(wxWindow *pParent, CSG_Grid *pDrape = NULL);
+	virtual ~CSG_3DView_Panel(void);
 
 	CSG_Parameters				m_Parameters;
 
+	CSG_Parameters &			Get_Parameters			(bool bUpdate = true);
+	bool						Set_Parameters			(CSG_Parameters *pParameters = NULL);
+
 	virtual bool				Update_Parameters		(bool bSave);
 	virtual bool				Update_View				(bool bStatistics = false);
 
+	bool						Parameters_Dialog		(void);
+
 	bool						Parameter_Value_Toggle	(const CSG_String &ID              , bool bUpdate = true);
 	bool						Parameter_Value_Add		(const CSG_String &ID, double Value, bool bUpdate = true);
 
 	static CSG_String			Get_Usage				(void);
 
+	bool						Set_Stereo_Mode			(int Mode);
+
 	bool						Save_asImage			(const CSG_String &FileName);
 	bool						Save_toClipboard		(void);
 
@@ -160,20 +168,22 @@ protected:
 
 private:
 
+	class CSG_3DView_Twin		*m_pTwin { NULL };
+
+
 	static int					_On_Parameter_Changed	(CSG_Parameter *pParameter, int Flags);
 
 	bool						_Play					(void);
 
 
 	DECLARE_EVENT_TABLE()
-
 };
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -188,7 +198,8 @@ enum
 	MENU_BOX,
 	MENU_LABELS,
 	MENU_NORTH,
-	MENU_STEREO,
+	MENU_ANAGLYPH,
+	MENU_STEREO_VIEW,
 	MENU_CENTRAL,
 	MENU_TO_CLIPBOARD,
 	MENU_ROTATE_X_INC,
@@ -214,7 +225,7 @@ enum
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -225,7 +236,7 @@ enum
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -266,9 +277,9 @@ private:
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
